@@ -50,7 +50,7 @@ class TrocketClient(AbstractClient):
 
 
     def CreateInstance(self, request):
-        """购买新实例
+        """创建 RocketMQ 5.x 集群
 
         :param request: Request instance for CreateInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.CreateInstanceRequest`
@@ -280,7 +280,7 @@ class TrocketClient(AbstractClient):
 
 
     def DeleteMQTTInstance(self, request):
-        """删除实例
+        """删除MQTT实例
 
         :param request: Request instance for DeleteMQTTInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteMQTTInstanceRequest`
@@ -303,7 +303,7 @@ class TrocketClient(AbstractClient):
 
 
     def DeleteMQTTTopic(self, request):
-        """删除主题
+        """删除MQTT主题
 
         :param request: Request instance for DeleteMQTTTopic.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteMQTTTopicRequest`
@@ -443,6 +443,34 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeFusionInstanceList(self, request):
+        """获取实例列表，Filters参数使用说明如下：
+        1. InstanceName, 名称模糊查询
+        2. InstanceId，实例ID查询
+        3. InstanceType, 实例类型查询，支持多选
+        4. Version，实例版本查询
+        当使用TagFilters查询时，Filters参数失效。
+
+        :param request: Request instance for DescribeFusionInstanceList.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeFusionInstanceListRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeFusionInstanceListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeFusionInstanceList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeFusionInstanceListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstance(self, request):
         """查询实例信息
 
@@ -686,7 +714,7 @@ class TrocketClient(AbstractClient):
 
 
     def DescribeMQTTProductSKUList(self, request):
-        """非对外接口，获取产品售卖规格
+        """获取产品售卖规格
 
         :param request: Request instance for DescribeMQTTProductSKUList.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMQTTProductSKUListRequest`
@@ -782,6 +810,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeProductSKUs(self, request):
+        """查询产品售卖规格，针对 RocketMQ 5.x 集群。
+
+        :param request: Request instance for DescribeProductSKUs.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeProductSKUsRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeProductSKUsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProductSKUs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeProductSKUsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRoleList(self, request):
         """查询角色列表，Filter参数使用说明如下：
 
@@ -951,7 +1002,7 @@ class TrocketClient(AbstractClient):
 
 
     def ModifyMQTTInsPublicEndpoint(self, request):
-        """为MQTT实例创建公网接入点
+        """更新MQTT实例公网接入点
 
         :param request: Request instance for ModifyMQTTInsPublicEndpoint.
         :type request: :class:`tencentcloud.trocket.v20230308.models.ModifyMQTTInsPublicEndpointRequest`
